debug_event

Macro debug_event 

macro_rules! debug_event {
    ($event_name:literal $(, $($fields:tt)+)?) => { ... };
}
Emit an event at the debug level

This macro creates an Event for the purpose of instrumenting code to measure the execution time between events.

If the tracing feature (of the crate using this macro) is disabled, this macro expands to nothing.

Attention: This macro requires the user crate to have a tracing feature, which can be used to disable the effects of this macro.