macro_rules! trace_event {
($event_name:literal $(, $($fields:tt)+)?) => { ... };
}Expand description
Emit an event at the trace level
This macro creates an Event for the purpose of instrumenting code to measure the execution time between events.
If the tracing feature (of the crate using this macro) is disabled, this
macro expands to nothing.
Attention: This macro requires the user crate to have a tracing feature,
which can be used to disable the effects of this macro.